@@ -34,7 +34,10 @@ TopdownTileSet::~TopdownTileSet() {
 
 void TopdownTileSet::mapChunkToTiles(const mc::ChunkPos& chunk,
 		std::set<TilePos>& tiles) {
-	tiles.insert(TilePos(chunk.x / getTileWidth(), chunk.z / getTileWidth()));
+	// make sure we render towards -infinity
+	int x = std::floor((float) chunk.x / getTileWidth());
+	int y = std::floor((float) chunk.z / getTileWidth());
+	tiles.insert(TilePos(x, y));
 }
 
 }
